## [0.0.6] – 2025-06-18
### Added
- turn featuremap into rgb plot via find first 3 pca component 
### Changed
- return fig for grid_plot_list_imgs 


# Changelog

## 1.5.1 2025-11-19
## Added
- ncut module
